mathtools.is_nonnegative_integer_power_of_two
=============================================

.. autofunction:: abjad.tools.mathtools.is_nonnegative_integer_power_of_two.is_nonnegative_integer_power_of_two
